@@ -3,7 +3,7 @@ from __future__ import division
 from __future__ import print_function
 from __future__ import unicode_literals
 
-import onnx.onnx_cpp2py_export as C
+import onnx.onnx_cpp2py_export.defs as C
 
 
 def has(op_type):
@@ -18,7 +18,12 @@ def get_all_schemas():
     return C.get_all_schemas()
 
 
-def verify(schema, node_proto):
-    return schema.verify(node_proto.SerializeToString())
+def get_all_schemas_with_history():
+    return C.get_all_schemas_with_history()
+
+
+def onnx_opset_version():
+    return C.schema_version_map()[""][1]
+
 
 OpSchema = C.OpSchema
